summaryrefslogtreecommitdiff
path: root/chromium/components/url_pattern_index/url_rule_test_support.h
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/components/url_pattern_index/url_rule_test_support.h')
-rw-r--r--chromium/components/url_pattern_index/url_rule_test_support.h10
1 files changed, 6 insertions, 4 deletions
diff --git a/chromium/components/url_pattern_index/url_rule_test_support.h b/chromium/components/url_pattern_index/url_rule_test_support.h
index 895f0f8446a..e051575fcb0 100644
--- a/chromium/components/url_pattern_index/url_rule_test_support.h
+++ b/chromium/components/url_pattern_index/url_rule_test_support.h
@@ -55,11 +55,13 @@ constexpr proto::SourceType kFirstParty = proto::SOURCE_TYPE_FIRST_PARTY;
// initialized to defaults.
proto::UrlRule MakeUrlRule(const UrlPattern& url_pattern = UrlPattern());
// Parses |domains| and adds them to the domain list of the |rule|.
//
-// The |domains| vector should contain non-empty strings. If a string starts
-// with '~' then the following part of the string is an exception domain.
-void AddDomains(const std::vector<std::string>& domains, proto::UrlRule* rule);
+// The `initiator_domains` vector should contain non-empty strings. If a string
+// starts with '~' then the following part of the string is an exception domain.
+void AddInitiatorDomains(const std::vector<std::string>& initiator_domains,
+ proto::UrlRule* rule);
// Returns the url::Origin parsed from |origin_string|, or the unique origin if
// the string is empty.
@@ -55,11 +55,13 @@ constexpr proto::SourceType kFirstParty = proto::SOURCE_TYPE_FIRST_PARTY;
// initialized to defaults.
proto::UrlRule MakeUrlRule(const UrlPattern& url_pattern = UrlPattern());
-// Parses |domains| and adds them to the domain list of the |rule|.
+// Parses `initiator_domains` and adds them to the initiator domain list of the
+// `rule`.
//